GameViewResult class

Result returned when a marketplace game finishes.

Constructors

GameViewResult({required bool won, String? prizeCode, int? score, Map<String, dynamic> metadata = const {}})
const

Properties

hashCode int
The hash code for this object.
no setterinherited
metadata Map<String, dynamic>
final
prizeCode String?
final
runtimeType Type
A representation of the runtime type of the object.
no setterinherited
score int?
final
won bool
final

Methods

noSuchMethod(Invocation invocation) → dynamic
Invoked when a nonexistent method or property is accessed.
inherited
toString() String
A string representation of this object.
inherited

Operators

operator ==(Object other) bool
The equality operator.
inherited